==> qore-0.9.4.tar.bz2: qore-0.9.4/docs/modules/CsvUtil/html/navtreedata.js <==
/*
@ @licstart  The following is the entire license notice for the
JavaScript code in this file.

Copyright (C) 1997-2017 by Dimitri van Heesch

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.

@licend  The above is the entire license notice
for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "Qore CsvUtil Module Reference", "index.html", [
    [ "CsvUtil Module", "index.html", [
      [ "Introduction to the CsvUtil Module", "index.html#csvutilintro", null ],
      [ "Multi-type support", "index.html#csvutil_multitype", null ],
      [ "Release Notes", "index.html#csvutil_relnotes", [
        [ "Version 1.7", "index.html#csvutil_v1_7", null ],
        [ "Version 1.6.2", "index.html#csvutil_v1_6_2", null ],
        [ "Version 1.6.1", "index.html#csvutil_v1_6_1", null ],
        [ "Version 1.6", "index.html#csvutil_v1_6", null ],
        [ "Version 1.5.1", "index.html#csvutil_v1_5_1", null ],
        [ "Version 1.5", "index.html#csvutil_v1_5", null ],
        [ "Version 1.4", "index.html#csvutil_v1_4", null ],
        [ "Version 1.3", "index.html#csvutil_v1_3", null ],
        [ "Version 1.2", "index.html#csvutil_v1_2", null ],
        [ "Version 1.1", "index.html#csvutil_v1_1", null ],
        [ "Version 1.0", "index.html#csvutil_v1_0", null ]
      ] ]
    ] ],
    [ "Namespaces", "namespaces.html", [
      [ "Namespace List", "namespaces.html", "namespaces_dup" ],
      [ "Namespace Members", "namespacemembers.html", [
        [ "All", "namespacemembers.html", null ],
        [ "Functions", "namespacemembers_func.html", null ],
        [ "Variables", "namespacemembers_vars.html", null ]
      ] ]
    ] ],
    [ "Classes", "annotated.html", [
      [ "Class List", "annotated.html", "annotated_dup" ],
      [ "Class Index", "classes.html", null ],
      [ "Class Hierarchy", "hierarchy.html", "hierarchy" ],
      [ "Class Members", "functions.html", [
        [ "All", "functions.html", null ],
        [ "Functions", "functions_func.html", null ],
        [ "Variables", "functions_vars.html", null ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"annotated.html"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';

==> qore-0.9.4.1.tar.bz2: qore-0.9.4.1/docs/modules/CsvUtil/html/navtreedata.js <==
/*
@licstart  The following is the entire license notice for the
JavaScript code in this file.

Copyright (C) 1997-2019 by Dimitri van Heesch

This program is free software; you can redistribute it and/or modify
it under the terms of version 2 of the GNU General Public License as published by
the Free Software Foundation

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.

@licend  The above is the entire license notice
for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "Qore CsvUtil Module Reference", "index.html", [
    [ "CsvUtil Module", "index.html", [
      [ "Introduction to the CsvUtil Module", "index.html#csvutilintro", null ],
      [ "Multi-type support", "index.html#csvutil_multitype", null ],
      [ "Release Notes", "index.html#csvutil_relnotes", [
        [ "Version 1.7", "index.html#csvutil_v1_7", null ],
        [ "Version 1.6.2", "index.html#csvutil_v1_6_2", null ],
        [ "Version 1.6.1", "index.html#csvutil_v1_6_1", null ],
        [ "Version 1.6", "index.html#csvutil_v1_6", null ],
        [ "Version 1.5.1", "index.html#csvutil_v1_5_1", null ],
        [ "Version 1.5", "index.html#csvutil_v1_5", null ],
        [ "Version 1.4", "index.html#csvutil_v1_4", null ],
        [ "Version 1.3", "index.html#csvutil_v1_3", null ],
        [ "Version 1.2", "index.html#csvutil_v1_2", null ],
        [ "Version 1.1", "index.html#csvutil_v1_1", null ],
        [ "Version 1.0", "index.html#csvutil_v1_0", null ]
      ] ]
    ] ],
    [ "Namespaces", "namespaces.html", [
      [ "Namespace List", "namespaces.html", "namespaces_dup" ],
      [ "Namespace Members", "namespacemembers.html", [
        [ "All", "namespacemembers.html", null ],
        [ "Functions", "namespacemembers_func.html", null ],
        [ "Variables", "namespacemembers_vars.html", null ]
      ] ]
    ] ],
    [ "Classes", "annotated.html", [
      [ "Class List", "annotated.html", "annotated_dup" ],
      [ "Class Index", "classes.html", null ],
      [ "Class Hierarchy", "hierarchy.html", "hierarchy" ],
      [ "Class Members", "functions.html", [
        [ "All", "functions.html", null ],
        [ "Functions", "functions_func.html", null ],
        [ "Variables", "functions_vars.html", null ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"annotated.html"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';
